pub struct IoMem<SecuritySensitivity = Insensitive> { /* private fields */ }Expand description
I/O memory.
Implementations
Sourceimpl<SecuritySensitivity> IoMem<SecuritySensitivity>
impl<SecuritySensitivity> IoMem<SecuritySensitivity>
Sourcepub fn slice(&self, range: Range<usize>) -> Self
pub fn slice(&self, range: Range<usize>) -> Self
Slices the IoMem, returning another IoMem representing the subslice.
Panics
This method will panic if the range is empty or out of bounds.
Sourcepub fn cache_policy(&self) -> CachePolicy
pub fn cache_policy(&self) -> CachePolicy
Returns the cache policy of this IoMem.
Sourceimpl IoMem<Insensitive>
impl IoMem<Insensitive>
Sourcepub fn acquire(range: Range<Paddr>) -> Result<IoMem<Insensitive>>
pub fn acquire(range: Range<Paddr>) -> Result<IoMem<Insensitive>>
Acquires an IoMem instance for the given range.
The I/O memory cache policy is set to uncacheable by default.
Sourcepub fn acquire_with_cache_policy(
range: Range<Paddr>,
cache_policy: CachePolicy,
) -> Result<IoMem<Insensitive>>
pub fn acquire_with_cache_policy( range: Range<Paddr>, cache_policy: CachePolicy, ) -> Result<IoMem<Insensitive>>
Acquires an IoMem instance for the given range with the specified cache policy.
Sourcepub fn read_fallible(
&self,
offset: usize,
writer: &mut VmWriter<'_>,
) -> Result<usize, (Error, usize)>
pub fn read_fallible( &self, offset: usize, writer: &mut VmWriter<'_>, ) -> Result<usize, (Error, usize)>
Reads from MMIO into fallible memory and returns the copied length.
This method performs the same low-level copy primitive as VmIo::read,
but exposes partial progress instead of enforcing no-short-read semantics.
Sourcepub fn write_fallible(
&self,
offset: usize,
reader: &mut VmReader<'_>,
) -> Result<usize, (Error, usize)>
pub fn write_fallible( &self, offset: usize, reader: &mut VmReader<'_>, ) -> Result<usize, (Error, usize)>
Writes from fallible memory to MMIO and returns the copied length.
This method performs the same low-level copy primitive as VmIo::write,
but exposes partial progress instead of enforcing no-short-write semantics.